@@ -9,6 +9,7 @@ import xmltodict
 from urllib.parse import urlparse
 from concurrent.futures import ThreadPoolExecutor
 from concurrent.futures import as_completed
+from requests_toolbelt.utils import dump
 
 requests.packages.urllib3.disable_warnings()
 normalval="discobiscuits"
@@ -36,14 +37,14 @@ class Fuzzer(Thread):
         self.originalresponse = {}
         with open(wordlist) as read:
             self.lines=read.read().splitlines()
-        
+
     def brute(self,params_group,reqtype):
         params_group.update(self.baseParams)
         response = self.request(params_group,reqtype)
         #now we compare to original if not similar then return params_group else return None
         res = self.compare(reqtype,response)
-        if res[2]!="":
-            return {"reflects":res[0],"different_type":res[1],"diffs":res[2],"parameters":params_group,"request_type":reqtype,"value_type":self.value_type}
+        if res[6]!="":
+            return {"status_code":res[0],"reflects":res[1],"words":res[2],"bytes":res[3],"different_type":res[4],"different_status":res[5],"diffs":res[6],"request":dump.dump_response(response,request_prefix="").decode('utf-8','ignore').split("\r\n>")[0]}
         return None
     
     def request(self,params_group,reqtype):
@@ -419,41 +420,35 @@ class Fuzzer(Thread):
         return {"size_of_headers":size_of_headers,"num_of_lines":num_of_lines,"num_of_cookies":num_of_cookies,"status_code":status_code,"num_of_bytes":num_of_bytes,"num_of_words":num_of_words,"num_of_reflects":num_of_reflects,"num_of_headers":num_of_headers,"content_type":content_type}
             
     def compare(self,reqtype,response):
+        if response == None:
+            return (0,0,0,0,False,False,"")
         diffs=""
-        rate = 0
         diff = False #different content type
+        status_diff = False #different status code
         props = self.getResponseProps(response)
         if props["num_of_reflects"] > 0: #!= self.originalresponse[reqtype]["num_of_reflects"]:
             diffs+="Reflect-"
-            rate+=1
         if self.originalresponse[reqtype] == {}:
-            return (props["num_of_reflects"],diff,diffs.strip("-"))
+            return (props["status_code"],props["num_of_reflects"],props["num_of_words"],props["num_of_bytes"],diff,status_diff,diffs.strip("-"))
         if props["content_type"]!=self.originalresponse[reqtype]["content_type"]:
             diffs+="Content_Type-"
-            rate+=1
             diff = True
         if props["status_code"]!=self.originalresponse[reqtype]["status_code"]:
             diffs+="Status_Code-"
-            rate+=1
+            status_diff = True
         if props["num_of_words"]!=self.originalresponse[reqtype]["num_of_words"]:
             diffs+="Words-"
-            rate+=1
         if props["num_of_lines"]!=self.originalresponse[reqtype]["num_of_lines"]:
             diffs+="Lines-"
-            rate+=1
         if abs(props["num_of_bytes"]-self.originalresponse[reqtype]["num_of_bytes"]) > 5:
             diffs+="Body Size-"
-            rate+=1
         if props["num_of_headers"]!=self.originalresponse[reqtype]["num_of_headers"]:
             diffs+="Headers Number-"
-            rate+=1
         if props["num_of_cookies"]!=self.originalresponse[reqtype]["num_of_cookies"]:
             diffs+="Cookies-"
-            rate+=1
         if abs(props["size_of_headers"]-self.originalresponse[reqtype]["size_of_headers"]) > 5:
             diffs+="Headers Size-"
-            rate+=1
-        return (props["num_of_reflects"],diff,diffs.strip("-"))
+        return (props["status_code"],props["num_of_reflects"],props["num_of_words"],props["num_of_bytes"],diff,status_diff,diffs.strip("-"))
         
             
     def calculateOriginal(self):
@@ -478,8 +473,8 @@ class Fuzzer(Thread):
                 self.originalresponse[reqtype] = self.getResponseProps(response)
                 if "base" in self.originalresponse:
                     res = self.compare("base",response)
-                    if res[2]!="":
-                         self.results_queue.put({"reflectsbase":res[0],"different_type":res[1],"diffs":res[2],"parameters":self.baseParams,"request_type":reqtype,"value_type":self.value_type})
+                    if res[6]!="":
+                         self.results_queue.put({"status_code":res[0],"reflects":res[1],"words":res[2],"bytes":res[3],"different_type":res[4],"different_status":res[5],"diffs":res[6],"request":dumprequest(response)})
             else:
                 self.originalresponse[reqtype] = {}        
                 
@@ -547,9 +542,6 @@ class ParamHammer:
         self.custom_value = custom_value
         self.wordlist = wordlist
         self.request_types = request_types
-        if self.value_type != "normal" and self.value_type != "bad":
-            if self.custom_value == "":
-                self.custom_value = "discobiscuits"
         fuzzer = Fuzzer(self.results_queue,self.url,self.method,self.headers,self.body,self.request_types,self.num_of_params,self.num_of_threads,self.delay,self.wordlist,self.value_type,self.custom_value)
         fuzzer.start()
         
